powered by
Creates a Shiny UI input binding to a histogram with a slider "filter" control.
input_histoslider( id, label, values, start = NULL, end = NULL, width = "100%", height = 175, breaks = rlang::missing_arg(), options = list() )
A Shiny UI input element.
An input id.
A label for the input (can be NULL or a string).
NULL
a vector of numeric values for which the histogram is desired.
A numeric value for the starting handle.
A numeric value for the ending handle.
Any valid CSS unit defining the width/height.
determines how histogram bins are computed (see hist() for possible values and details).
hist()
a list of histoslider options.
update_histoslider
if (interactive()) { library(shiny) shinyApp( input_histoslider("x", "Random", rnorm(100)), function(input, output) { observe(print(input$x)) } ) }
Run the code above in your browser using DataLab