Change the value of a input_histoslider() on the client (must be called
inside a currently active user session). See
here
for an example.
update_histoslider(
id,
label = NULL,
values = NULL,
start = NULL,
end = NULL,
breaks = rlang::missing_arg(),
options = NULL,
session = shiny::getDefaultReactiveDomain()
)Nothing.
An input id.
A label for the input (can be NULL or a string).
a vector of numeric values for which the histogram is desired.
A numeric value for the starting handle.
A numeric value for the ending handle.
determines how histogram bins are computed (see hist() for
possible values and details).
a list of histoslider options.
The shiny user session object.
Any arguments with NULL values will be ignored; they will not
result in any changes to the input object on the client.
input_histoslider